# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class RecaptchaRequiredError(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'error_type': 'str',
        'error_code': 'str',
        'display_message': 'str',
        'http_code': 'str',
        'link_user_experience': 'str',
        'common_causes': 'str',
        'troubleshooting_steps': 'str'
    }

    attribute_map = {
        'error_type': 'error_type',
        'error_code': 'error_code',
        'display_message': 'display_message',
        'http_code': 'http_code',
        'link_user_experience': 'link_user_experience',
        'common_causes': 'common_causes',
        'troubleshooting_steps': 'troubleshooting_steps'
    }

    def __init__(self, error_type=None, error_code=None, display_message=None, http_code=None, link_user_experience=None, common_causes=None, troubleshooting_steps=None, local_vars_configuration=None):  # noqa: E501
        """RecaptchaRequiredError - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._error_type = None
        self._error_code = None
        self._display_message = None
        self._http_code = None
        self._link_user_experience = None
        self._common_causes = None
        self._troubleshooting_steps = None
        self.discriminator = None

        if error_type is not None:
            self.error_type = error_type
        if error_code is not None:
            self.error_code = error_code
        if display_message is not None:
            self.display_message = display_message
        if http_code is not None:
            self.http_code = http_code
        if link_user_experience is not None:
            self.link_user_experience = link_user_experience
        if common_causes is not None:
            self.common_causes = common_causes
        if troubleshooting_steps is not None:
            self.troubleshooting_steps = troubleshooting_steps

    @property
    def error_type(self):
        """Gets the error_type of this RecaptchaRequiredError.  # noqa: E501

        RECAPTCHA_ERROR  # noqa: E501

        :return: The error_type of this RecaptchaRequiredError.  # noqa: E501
        :rtype: str
        """
        return self._error_type

    @error_type.setter
    def error_type(self, error_type):
        """Sets the error_type of this RecaptchaRequiredError.

        RECAPTCHA_ERROR  # noqa: E501

        :param error_type: The error_type of this RecaptchaRequiredError.  # noqa: E501
        :type error_type: str
        """

        self._error_type = error_type

    @property
    def error_code(self):
        """Gets the error_code of this RecaptchaRequiredError.  # noqa: E501

        RECAPTCHA_REQUIRED  # noqa: E501

        :return: The error_code of this RecaptchaRequiredError.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this RecaptchaRequiredError.

        RECAPTCHA_REQUIRED  # noqa: E501

        :param error_code: The error_code of this RecaptchaRequiredError.  # noqa: E501
        :type error_code: str
        """

        self._error_code = error_code

    @property
    def display_message(self):
        """Gets the display_message of this RecaptchaRequiredError.  # noqa: E501


        :return: The display_message of this RecaptchaRequiredError.  # noqa: E501
        :rtype: str
        """
        return self._display_message

    @display_message.setter
    def display_message(self, display_message):
        """Sets the display_message of this RecaptchaRequiredError.


        :param display_message: The display_message of this RecaptchaRequiredError.  # noqa: E501
        :type display_message: str
        """

        self._display_message = display_message

    @property
    def http_code(self):
        """Gets the http_code of this RecaptchaRequiredError.  # noqa: E501

        400  # noqa: E501

        :return: The http_code of this RecaptchaRequiredError.  # noqa: E501
        :rtype: str
        """
        return self._http_code

    @http_code.setter
    def http_code(self, http_code):
        """Sets the http_code of this RecaptchaRequiredError.

        400  # noqa: E501

        :param http_code: The http_code of this RecaptchaRequiredError.  # noqa: E501
        :type http_code: str
        """

        self._http_code = http_code

    @property
    def link_user_experience(self):
        """Gets the link_user_experience of this RecaptchaRequiredError.  # noqa: E501

        Your user will be prompted to solve a Google reCAPTCHA challenge in the Link Recaptcha pane. If they solve the challenge successfully, the user's request is resubmitted and they are directed to the next Item creation step.  # noqa: E501

        :return: The link_user_experience of this RecaptchaRequiredError.  # noqa: E501
        :rtype: str
        """
        return self._link_user_experience

    @link_user_experience.setter
    def link_user_experience(self, link_user_experience):
        """Sets the link_user_experience of this RecaptchaRequiredError.

        Your user will be prompted to solve a Google reCAPTCHA challenge in the Link Recaptcha pane. If they solve the challenge successfully, the user's request is resubmitted and they are directed to the next Item creation step.  # noqa: E501

        :param link_user_experience: The link_user_experience of this RecaptchaRequiredError.  # noqa: E501
        :type link_user_experience: str
        """

        self._link_user_experience = link_user_experience

    @property
    def common_causes(self):
        """Gets the common_causes of this RecaptchaRequiredError.  # noqa: E501

        Plaid's fraud system detects abusive traffic and considers a variety of parameters throughout Item creation requests. When a request is considered risky or possibly fraudulent, Link presents a reCAPTCHA for the user to solve.  # noqa: E501

        :return: The common_causes of this RecaptchaRequiredError.  # noqa: E501
        :rtype: str
        """
        return self._common_causes

    @common_causes.setter
    def common_causes(self, common_causes):
        """Sets the common_causes of this RecaptchaRequiredError.

        Plaid's fraud system detects abusive traffic and considers a variety of parameters throughout Item creation requests. When a request is considered risky or possibly fraudulent, Link presents a reCAPTCHA for the user to solve.  # noqa: E501

        :param common_causes: The common_causes of this RecaptchaRequiredError.  # noqa: E501
        :type common_causes: str
        """

        self._common_causes = common_causes

    @property
    def troubleshooting_steps(self):
        """Gets the troubleshooting_steps of this RecaptchaRequiredError.  # noqa: E501

        Link will automatically guide your user through reCAPTCHA verification. As a general rule, we recommend instrumenting basic fraud monitoring to detect and protect your website from spam and abuse.  If your user cannot verify their session, please submit a Support ticket with the following identifiers: `link_session_id` or `request_id`  # noqa: E501

        :return: The troubleshooting_steps of this RecaptchaRequiredError.  # noqa: E501
        :rtype: str
        """
        return self._troubleshooting_steps

    @troubleshooting_steps.setter
    def troubleshooting_steps(self, troubleshooting_steps):
        """Sets the troubleshooting_steps of this RecaptchaRequiredError.

        Link will automatically guide your user through reCAPTCHA verification. As a general rule, we recommend instrumenting basic fraud monitoring to detect and protect your website from spam and abuse.  If your user cannot verify their session, please submit a Support ticket with the following identifiers: `link_session_id` or `request_id`  # noqa: E501

        :param troubleshooting_steps: The troubleshooting_steps of this RecaptchaRequiredError.  # noqa: E501
        :type troubleshooting_steps: str
        """

        self._troubleshooting_steps = troubleshooting_steps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecaptchaRequiredError):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RecaptchaRequiredError):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class AuthGetNumbers(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ach': 'list[NumbersACH]',
        'eft': 'list[NumbersEFT]',
        'international': 'list[NumbersInternational]',
        'bacs': 'list[NumbersBACS]'
    }

    attribute_map = {
        'ach': 'ach',
        'eft': 'eft',
        'international': 'international',
        'bacs': 'bacs'
    }

    def __init__(self, ach=None, eft=None, international=None, bacs=None, local_vars_configuration=None):  # noqa: E501
        """AuthGetNumbers - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ach = None
        self._eft = None
        self._international = None
        self._bacs = None
        self.discriminator = None

        if ach is not None:
            self.ach = ach
        if eft is not None:
            self.eft = eft
        if international is not None:
            self.international = international
        if bacs is not None:
            self.bacs = bacs

    @property
    def ach(self):
        """Gets the ach of this AuthGetNumbers.  # noqa: E501

        An array of ACH numbers identifying accounts.  # noqa: E501

        :return: The ach of this AuthGetNumbers.  # noqa: E501
        :rtype: list[NumbersACH]
        """
        return self._ach

    @ach.setter
    def ach(self, ach):
        """Sets the ach of this AuthGetNumbers.

        An array of ACH numbers identifying accounts.  # noqa: E501

        :param ach: The ach of this AuthGetNumbers.  # noqa: E501
        :type ach: list[NumbersACH]
        """

        self._ach = ach

    @property
    def eft(self):
        """Gets the eft of this AuthGetNumbers.  # noqa: E501

        An array of EFT numbers identifying accounts.  # noqa: E501

        :return: The eft of this AuthGetNumbers.  # noqa: E501
        :rtype: list[NumbersEFT]
        """
        return self._eft

    @eft.setter
    def eft(self, eft):
        """Sets the eft of this AuthGetNumbers.

        An array of EFT numbers identifying accounts.  # noqa: E501

        :param eft: The eft of this AuthGetNumbers.  # noqa: E501
        :type eft: list[NumbersEFT]
        """

        self._eft = eft

    @property
    def international(self):
        """Gets the international of this AuthGetNumbers.  # noqa: E501

        An array of IBAN numbers identifying accounts.  # noqa: E501

        :return: The international of this AuthGetNumbers.  # noqa: E501
        :rtype: list[NumbersInternational]
        """
        return self._international

    @international.setter
    def international(self, international):
        """Sets the international of this AuthGetNumbers.

        An array of IBAN numbers identifying accounts.  # noqa: E501

        :param international: The international of this AuthGetNumbers.  # noqa: E501
        :type international: list[NumbersInternational]
        """

        self._international = international

    @property
    def bacs(self):
        """Gets the bacs of this AuthGetNumbers.  # noqa: E501

        An array of BACS numbers identifying accounts.  # noqa: E501

        :return: The bacs of this AuthGetNumbers.  # noqa: E501
        :rtype: list[NumbersBACS]
        """
        return self._bacs

    @bacs.setter
    def bacs(self, bacs):
        """Sets the bacs of this AuthGetNumbers.

        An array of BACS numbers identifying accounts.  # noqa: E501

        :param bacs: The bacs of this AuthGetNumbers.  # noqa: E501
        :type bacs: list[NumbersBACS]
        """

        self._bacs = bacs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuthGetNumbers):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuthGetNumbers):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from plaid.generated_plaid.models.ach_class import ACHClass
from plaid.generated_plaid.models.apr import APR
from plaid.generated_plaid.models.account_assets import AccountAssets
from plaid.generated_plaid.models.account_assets_all_of import AccountAssetsAllOf
from plaid.generated_plaid.models.account_balance import AccountBalance
from plaid.generated_plaid.models.account_base import AccountBase
from plaid.generated_plaid.models.account_filters_response import AccountFiltersResponse
from plaid.generated_plaid.models.account_identity import AccountIdentity
from plaid.generated_plaid.models.account_identity_all_of import AccountIdentityAllOf
from plaid.generated_plaid.models.account_subtype import AccountSubtype
from plaid.generated_plaid.models.account_type import AccountType
from plaid.generated_plaid.models.accounts_get_request import AccountsGetRequest
from plaid.generated_plaid.models.accounts_get_request_options import AccountsGetRequestOptions
from plaid.generated_plaid.models.accounts_get_response import AccountsGetResponse
from plaid.generated_plaid.models.address import Address
from plaid.generated_plaid.models.address_data import AddressData
from plaid.generated_plaid.models.amount import Amount
from plaid.generated_plaid.models.asset_report import AssetReport
from plaid.generated_plaid.models.asset_report_audit_copy_create_request import AssetReportAuditCopyCreateRequest
from plaid.generated_plaid.models.asset_report_audit_copy_create_response import AssetReportAuditCopyCreateResponse
from plaid.generated_plaid.models.asset_report_audit_copy_get_request import AssetReportAuditCopyGetRequest
from plaid.generated_plaid.models.asset_report_audit_copy_remove_request import AssetReportAuditCopyRemoveRequest
from plaid.generated_plaid.models.asset_report_audit_copy_remove_response import AssetReportAuditCopyRemoveResponse
from plaid.generated_plaid.models.asset_report_create_request import AssetReportCreateRequest
from plaid.generated_plaid.models.asset_report_create_request_options import AssetReportCreateRequestOptions
from plaid.generated_plaid.models.asset_report_create_response import AssetReportCreateResponse
from plaid.generated_plaid.models.asset_report_filter_request import AssetReportFilterRequest
from plaid.generated_plaid.models.asset_report_filter_response import AssetReportFilterResponse
from plaid.generated_plaid.models.asset_report_get_request import AssetReportGetRequest
from plaid.generated_plaid.models.asset_report_get_response import AssetReportGetResponse
from plaid.generated_plaid.models.asset_report_item import AssetReportItem
from plaid.generated_plaid.models.asset_report_pdf_get_request import AssetReportPDFGetRequest
from plaid.generated_plaid.models.asset_report_refresh_request import AssetReportRefreshRequest
from plaid.generated_plaid.models.asset_report_refresh_request_options import AssetReportRefreshRequestOptions
from plaid.generated_plaid.models.asset_report_refresh_response import AssetReportRefreshResponse
from plaid.generated_plaid.models.asset_report_remove_request import AssetReportRemoveRequest
from plaid.generated_plaid.models.asset_report_remove_response import AssetReportRemoveResponse
from plaid.generated_plaid.models.asset_report_user import AssetReportUser
from plaid.generated_plaid.models.assets_error_webhook import AssetsErrorWebhook
from plaid.generated_plaid.models.assets_product_ready_webhook import AssetsProductReadyWebhook
from plaid.generated_plaid.models.auth_get_numbers import AuthGetNumbers
from plaid.generated_plaid.models.auth_get_request import AuthGetRequest
from plaid.generated_plaid.models.auth_get_request_options import AuthGetRequestOptions
from plaid.generated_plaid.models.auth_get_response import AuthGetResponse
from plaid.generated_plaid.models.automatically_verified_webhook import AutomaticallyVerifiedWebhook
from plaid.generated_plaid.models.balance_get_request import BalanceGetRequest
from plaid.generated_plaid.models.balance_get_request_options import BalanceGetRequestOptions
from plaid.generated_plaid.models.balance_get_response import BalanceGetResponse
from plaid.generated_plaid.models.bank_transfer import BankTransfer
from plaid.generated_plaid.models.bank_transfer_balance import BankTransferBalance
from plaid.generated_plaid.models.bank_transfer_balance_get_request import BankTransferBalanceGetRequest
from plaid.generated_plaid.models.bank_transfer_balance_get_response import BankTransferBalanceGetResponse
from plaid.generated_plaid.models.bank_transfer_cancel_request import BankTransferCancelRequest
from plaid.generated_plaid.models.bank_transfer_cancel_response import BankTransferCancelResponse
from plaid.generated_plaid.models.bank_transfer_create_request import BankTransferCreateRequest
from plaid.generated_plaid.models.bank_transfer_create_response import BankTransferCreateResponse
from plaid.generated_plaid.models.bank_transfer_direction import BankTransferDirection
from plaid.generated_plaid.models.bank_transfer_event import BankTransferEvent
from plaid.generated_plaid.models.bank_transfer_event_list_request import BankTransferEventListRequest
from plaid.generated_plaid.models.bank_transfer_event_list_response import BankTransferEventListResponse
from plaid.generated_plaid.models.bank_transfer_event_sync_request import BankTransferEventSyncRequest
from plaid.generated_plaid.models.bank_transfer_event_sync_response import BankTransferEventSyncResponse
from plaid.generated_plaid.models.bank_transfer_event_type import BankTransferEventType
from plaid.generated_plaid.models.bank_transfer_failure import BankTransferFailure
from plaid.generated_plaid.models.bank_transfer_get_request import BankTransferGetRequest
from plaid.generated_plaid.models.bank_transfer_get_response import BankTransferGetResponse
from plaid.generated_plaid.models.bank_transfer_list_request import BankTransferListRequest
from plaid.generated_plaid.models.bank_transfer_list_response import BankTransferListResponse
from plaid.generated_plaid.models.bank_transfer_migrate_account_request import BankTransferMigrateAccountRequest
from plaid.generated_plaid.models.bank_transfer_migrate_account_response import BankTransferMigrateAccountResponse
from plaid.generated_plaid.models.bank_transfer_network import BankTransferNetwork
from plaid.generated_plaid.models.bank_transfer_receiver_details import BankTransferReceiverDetails
from plaid.generated_plaid.models.bank_transfer_status import BankTransferStatus
from plaid.generated_plaid.models.bank_transfer_type import BankTransferType
from plaid.generated_plaid.models.bank_transfer_user import BankTransferUser
from plaid.generated_plaid.models.categories_get_response import CategoriesGetResponse
from plaid.generated_plaid.models.category import Category
from plaid.generated_plaid.models.cause import Cause
from plaid.generated_plaid.models.country_code import CountryCode
from plaid.generated_plaid.models.credit_card_liability import CreditCardLiability
from plaid.generated_plaid.models.credit_filter import CreditFilter
from plaid.generated_plaid.models.default_update_webhook import DefaultUpdateWebhook
from plaid.generated_plaid.models.deposit_switch_create_request import DepositSwitchCreateRequest
from plaid.generated_plaid.models.deposit_switch_create_response import DepositSwitchCreateResponse
from plaid.generated_plaid.models.deposit_switch_get_request import DepositSwitchGetRequest
from plaid.generated_plaid.models.deposit_switch_get_response import DepositSwitchGetResponse
from plaid.generated_plaid.models.deposit_switch_token_create_request import DepositSwitchTokenCreateRequest
from plaid.generated_plaid.models.deposit_switch_token_create_response import DepositSwitchTokenCreateResponse
from plaid.generated_plaid.models.depository_filter import DepositoryFilter
from plaid.generated_plaid.models.email import Email
from plaid.generated_plaid.models.error import Error
from plaid.generated_plaid.models.external_payment_schedule import ExternalPaymentSchedule
from plaid.generated_plaid.models.historical_balance import HistoricalBalance
from plaid.generated_plaid.models.historical_update_webhook import HistoricalUpdateWebhook
from plaid.generated_plaid.models.holding import Holding
from plaid.generated_plaid.models.holdings_default_update_webhook import HoldingsDefaultUpdateWebhook
from plaid.generated_plaid.models.identity_get_request import IdentityGetRequest
from plaid.generated_plaid.models.identity_get_request_options import IdentityGetRequestOptions
from plaid.generated_plaid.models.identity_get_response import IdentityGetResponse
from plaid.generated_plaid.models.inflow_model import InflowModel
from plaid.generated_plaid.models.initial_update_webhook import InitialUpdateWebhook
from plaid.generated_plaid.models.institution import Institution
from plaid.generated_plaid.models.institution_status import InstitutionStatus
from plaid.generated_plaid.models.institutions_get_by_id_request import InstitutionsGetByIdRequest
from plaid.generated_plaid.models.institutions_get_by_id_request_options import InstitutionsGetByIdRequestOptions
from plaid.generated_plaid.models.institutions_get_by_id_response import InstitutionsGetByIdResponse
from plaid.generated_plaid.models.institutions_get_request import InstitutionsGetRequest
from plaid.generated_plaid.models.institutions_get_request_options import InstitutionsGetRequestOptions
from plaid.generated_plaid.models.institutions_get_response import InstitutionsGetResponse
from plaid.generated_plaid.models.institutions_search_request import InstitutionsSearchRequest
from plaid.generated_plaid.models.institutions_search_request_options import InstitutionsSearchRequestOptions
from plaid.generated_plaid.models.institutions_search_response import InstitutionsSearchResponse
from plaid.generated_plaid.models.investment_filter import InvestmentFilter
from plaid.generated_plaid.models.investment_holdings_get_request_options import InvestmentHoldingsGetRequestOptions
from plaid.generated_plaid.models.investment_transaction import InvestmentTransaction
from plaid.generated_plaid.models.investments_default_update_webhook import InvestmentsDefaultUpdateWebhook
from plaid.generated_plaid.models.investments_holdings_get_request import InvestmentsHoldingsGetRequest
from plaid.generated_plaid.models.investments_holdings_get_response import InvestmentsHoldingsGetResponse
from plaid.generated_plaid.models.investments_transactions_get_request import InvestmentsTransactionsGetRequest
from plaid.generated_plaid.models.investments_transactions_get_request_options import InvestmentsTransactionsGetRequestOptions
from plaid.generated_plaid.models.investments_transactions_get_response import InvestmentsTransactionsGetResponse
from plaid.generated_plaid.models.item import Item
from plaid.generated_plaid.models.item_access_token_invalidate_request import ItemAccessTokenInvalidateRequest
from plaid.generated_plaid.models.item_access_token_invalidate_response import ItemAccessTokenInvalidateResponse
from plaid.generated_plaid.models.item_error_webhook import ItemErrorWebhook
from plaid.generated_plaid.models.item_get_request import ItemGetRequest
from plaid.generated_plaid.models.item_get_response import ItemGetResponse
from plaid.generated_plaid.models.item_import_request import ItemImportRequest
from plaid.generated_plaid.models.item_import_request_options import ItemImportRequestOptions
from plaid.generated_plaid.models.item_import_request_user_auth import ItemImportRequestUserAuth
from plaid.generated_plaid.models.item_import_response import ItemImportResponse
from plaid.generated_plaid.models.item_product_ready_webhook import ItemProductReadyWebhook
from plaid.generated_plaid.models.item_public_token_create_request import ItemPublicTokenCreateRequest
from plaid.generated_plaid.models.item_public_token_create_response import ItemPublicTokenCreateResponse
from plaid.generated_plaid.models.item_public_token_exchange_request import ItemPublicTokenExchangeRequest
from plaid.generated_plaid.models.item_public_token_exchange_response import ItemPublicTokenExchangeResponse
from plaid.generated_plaid.models.item_remove_request import ItemRemoveRequest
from plaid.generated_plaid.models.item_remove_response import ItemRemoveResponse
from plaid.generated_plaid.models.item_status import ItemStatus
from plaid.generated_plaid.models.item_status_investments import ItemStatusInvestments
from plaid.generated_plaid.models.item_status_last_webhook import ItemStatusLastWebhook
from plaid.generated_plaid.models.item_status_transactions import ItemStatusTransactions
from plaid.generated_plaid.models.item_webhook_update_request import ItemWebhookUpdateRequest
from plaid.generated_plaid.models.item_webhook_update_response import ItemWebhookUpdateResponse
from plaid.generated_plaid.models.jwk_public_key import JWKPublicKey
from plaid.generated_plaid.models.jwt_header import JWTHeader
from plaid.generated_plaid.models.liabilities_get_request import LiabilitiesGetRequest
from plaid.generated_plaid.models.liabilities_get_request_options import LiabilitiesGetRequestOptions
from plaid.generated_plaid.models.liabilities_get_response import LiabilitiesGetResponse
from plaid.generated_plaid.models.liabilities_object import LiabilitiesObject
from plaid.generated_plaid.models.liability_override import LiabilityOverride
from plaid.generated_plaid.models.link_token_account_filters import LinkTokenAccountFilters
from plaid.generated_plaid.models.link_token_create_request import LinkTokenCreateRequest
from plaid.generated_plaid.models.link_token_create_request_account_subtypes import LinkTokenCreateRequestAccountSubtypes
from plaid.generated_plaid.models.link_token_create_request_account_subtypes_credit import LinkTokenCreateRequestAccountSubtypesCredit
from plaid.generated_plaid.models.link_token_create_request_account_subtypes_depository import LinkTokenCreateRequestAccountSubtypesDepository
from plaid.generated_plaid.models.link_token_create_request_account_subtypes_investment import LinkTokenCreateRequestAccountSubtypesInvestment
from plaid.generated_plaid.models.link_token_create_request_account_subtypes_loan import LinkTokenCreateRequestAccountSubtypesLoan
from plaid.generated_plaid.models.link_token_create_request_payment_initiation import LinkTokenCreateRequestPaymentInitiation
from plaid.generated_plaid.models.link_token_create_request_user import LinkTokenCreateRequestUser
from plaid.generated_plaid.models.link_token_create_response import LinkTokenCreateResponse
from plaid.generated_plaid.models.link_token_get_metadata_response import LinkTokenGetMetadataResponse
from plaid.generated_plaid.models.link_token_get_request import LinkTokenGetRequest
from plaid.generated_plaid.models.link_token_get_response import LinkTokenGetResponse
from plaid.generated_plaid.models.loan_filter import LoanFilter
from plaid.generated_plaid.models.location import Location
from plaid.generated_plaid.models.mfa import MFA
from plaid.generated_plaid.models.meta import Meta
from plaid.generated_plaid.models.mortgage_interest_rate import MortgageInterestRate
from plaid.generated_plaid.models.mortgage_liability import MortgageLiability
from plaid.generated_plaid.models.mortgage_property_address import MortgagePropertyAddress
from plaid.generated_plaid.models.numbers import Numbers
from plaid.generated_plaid.models.numbers_ach import NumbersACH
from plaid.generated_plaid.models.numbers_bacs import NumbersBACS
from plaid.generated_plaid.models.numbers_eft import NumbersEFT
from plaid.generated_plaid.models.numbers_international import NumbersInternational
from plaid.generated_plaid.models.override_accounts import OverrideAccounts
from plaid.generated_plaid.models.owner import Owner
from plaid.generated_plaid.models.owner_override import OwnerOverride
from plaid.generated_plaid.models.pslf_status import PSLFStatus
from plaid.generated_plaid.models.payment_amount import PaymentAmount
from plaid.generated_plaid.models.payment_initiation_address import PaymentInitiationAddress
from plaid.generated_plaid.models.payment_initiation_payment_create_request import PaymentInitiationPaymentCreateRequest
from plaid.generated_plaid.models.payment_initiation_payment_create_response import PaymentInitiationPaymentCreateResponse
from plaid.generated_plaid.models.payment_initiation_payment_get_request import PaymentInitiationPaymentGetRequest
from plaid.generated_plaid.models.payment_initiation_payment_get_response import PaymentInitiationPaymentGetResponse
from plaid.generated_plaid.models.payment_initiation_payment_list_request import PaymentInitiationPaymentListRequest
from plaid.generated_plaid.models.payment_initiation_payment_list_response import PaymentInitiationPaymentListResponse
from plaid.generated_plaid.models.payment_initiation_payment_token_create_request import PaymentInitiationPaymentTokenCreateRequest
from plaid.generated_plaid.models.payment_initiation_payment_token_create_response import PaymentInitiationPaymentTokenCreateResponse
from plaid.generated_plaid.models.payment_initiation_recipient import PaymentInitiationRecipient
from plaid.generated_plaid.models.payment_initiation_recipient_create_request import PaymentInitiationRecipientCreateRequest
from plaid.generated_plaid.models.payment_initiation_recipient_create_response import PaymentInitiationRecipientCreateResponse
from plaid.generated_plaid.models.payment_initiation_recipient_get_request import PaymentInitiationRecipientGetRequest
from plaid.generated_plaid.models.payment_initiation_recipient_get_response import PaymentInitiationRecipientGetResponse
from plaid.generated_plaid.models.payment_initiation_recipient_list_request import PaymentInitiationRecipientListRequest
from plaid.generated_plaid.models.payment_initiation_recipient_list_response import PaymentInitiationRecipientListResponse
from plaid.generated_plaid.models.payment_meta import PaymentMeta
from plaid.generated_plaid.models.payment_status_update_webhook import PaymentStatusUpdateWebhook
from plaid.generated_plaid.models.pending_expiration_webhook import PendingExpirationWebhook
from plaid.generated_plaid.models.phone_number import PhoneNumber
from plaid.generated_plaid.models.processor_apex_processor_token_create_request import ProcessorApexProcessorTokenCreateRequest
from plaid.generated_plaid.models.processor_auth_get_request import ProcessorAuthGetRequest
from plaid.generated_plaid.models.processor_auth_get_response import ProcessorAuthGetResponse
from plaid.generated_plaid.models.processor_balance_get_request import ProcessorBalanceGetRequest
from plaid.generated_plaid.models.processor_balance_get_response import ProcessorBalanceGetResponse
from plaid.generated_plaid.models.processor_identity_get_request import ProcessorIdentityGetRequest
from plaid.generated_plaid.models.processor_identity_get_response import ProcessorIdentityGetResponse
from plaid.generated_plaid.models.processor_number import ProcessorNumber
from plaid.generated_plaid.models.processor_stripe_bank_account_token_create_request import ProcessorStripeBankAccountTokenCreateRequest
from plaid.generated_plaid.models.processor_stripe_bank_account_token_create_response import ProcessorStripeBankAccountTokenCreateResponse
from plaid.generated_plaid.models.processor_token_create_request import ProcessorTokenCreateRequest
from plaid.generated_plaid.models.processor_token_create_response import ProcessorTokenCreateResponse
from plaid.generated_plaid.models.product_status import ProductStatus
from plaid.generated_plaid.models.product_status_breakdown import ProductStatusBreakdown
from plaid.generated_plaid.models.products import Products
from plaid.generated_plaid.models.recaptcha_required_error import RecaptchaRequiredError
from plaid.generated_plaid.models.recipient_bacs import RecipientBACS
from plaid.generated_plaid.models.sandbox_bank_transfer_simulate_request import SandboxBankTransferSimulateRequest
from plaid.generated_plaid.models.sandbox_bank_transfer_simulate_response import SandboxBankTransferSimulateResponse
from plaid.generated_plaid.models.sandbox_item_fire_webhook_request import SandboxItemFireWebhookRequest
from plaid.generated_plaid.models.sandbox_item_fire_webhook_response import SandboxItemFireWebhookResponse
from plaid.generated_plaid.models.sandbox_item_reset_login_request import SandboxItemResetLoginRequest
from plaid.generated_plaid.models.sandbox_item_reset_login_response import SandboxItemResetLoginResponse
from plaid.generated_plaid.models.sandbox_item_set_verification_status_request import SandboxItemSetVerificationStatusRequest
from plaid.generated_plaid.models.sandbox_item_set_verification_status_response import SandboxItemSetVerificationStatusResponse
from plaid.generated_plaid.models.sandbox_processor_token_create_request import SandboxProcessorTokenCreateRequest
from plaid.generated_plaid.models.sandbox_processor_token_create_request_options import SandboxProcessorTokenCreateRequestOptions
from plaid.generated_plaid.models.sandbox_processor_token_create_response import SandboxProcessorTokenCreateResponse
from plaid.generated_plaid.models.sandbox_public_token_create_request import SandboxPublicTokenCreateRequest
from plaid.generated_plaid.models.sandbox_public_token_create_request_options import SandboxPublicTokenCreateRequestOptions
from plaid.generated_plaid.models.sandbox_public_token_create_request_options_transactions import SandboxPublicTokenCreateRequestOptionsTransactions
from plaid.generated_plaid.models.sandbox_public_token_create_response import SandboxPublicTokenCreateResponse
from plaid.generated_plaid.models.security import Security
from plaid.generated_plaid.models.servicer_address_data import ServicerAddressData
from plaid.generated_plaid.models.standalone_account_type import StandaloneAccountType
from plaid.generated_plaid.models.standalone_currency_code_list import StandaloneCurrencyCodeList
from plaid.generated_plaid.models.standalone_investment_transaction_subtype import StandaloneInvestmentTransactionSubtype
from plaid.generated_plaid.models.standalone_investment_transaction_type import StandaloneInvestmentTransactionType
from plaid.generated_plaid.models.student_loan import StudentLoan
from plaid.generated_plaid.models.student_loan_repayment_model import StudentLoanRepaymentModel
from plaid.generated_plaid.models.student_loan_status import StudentLoanStatus
from plaid.generated_plaid.models.student_repayment_plan import StudentRepaymentPlan
from plaid.generated_plaid.models.transaction import Transaction
from plaid.generated_plaid.models.transaction_code import TransactionCode
from plaid.generated_plaid.models.transaction_override import TransactionOverride
from plaid.generated_plaid.models.transactions_get_request import TransactionsGetRequest
from plaid.generated_plaid.models.transactions_get_request_options import TransactionsGetRequestOptions
from plaid.generated_plaid.models.transactions_get_response import TransactionsGetResponse
from plaid.generated_plaid.models.transactions_refresh_request import TransactionsRefreshRequest
from plaid.generated_plaid.models.transactions_refresh_response import TransactionsRefreshResponse
from plaid.generated_plaid.models.transactions_removed_webhook import TransactionsRemovedWebhook
from plaid.generated_plaid.models.user_custom_password import UserCustomPassword
from plaid.generated_plaid.models.user_permission_revoked_webhook import UserPermissionRevokedWebhook
from plaid.generated_plaid.models.verification_expired_webhook import VerificationExpiredWebhook
from plaid.generated_plaid.models.warning import Warning
from plaid.generated_plaid.models.webhook_update_acknowledged_webhook import WebhookUpdateAcknowledgedWebhook
from plaid.generated_plaid.models.webhook_verification_key_get_request import WebhookVerificationKeyGetRequest
from plaid.generated_plaid.models.webhook_verification_key_get_response import WebhookVerificationKeyGetResponse



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class PhoneNumber(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'data': 'str',
        'primary': 'bool',
        'type': 'str'
    }

    attribute_map = {
        'data': 'data',
        'primary': 'primary',
        'type': 'type'
    }

    def __init__(self, data=None, primary=None, type=None, local_vars_configuration=None):  # noqa: E501
        """PhoneNumber - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._data = None
        self._primary = None
        self._type = None
        self.discriminator = None

        if data is not None:
            self.data = data
        self.primary = primary
        self.type = type

    @property
    def data(self):
        """Gets the data of this PhoneNumber.  # noqa: E501

        The phone number.  # noqa: E501

        :return: The data of this PhoneNumber.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this PhoneNumber.

        The phone number.  # noqa: E501

        :param data: The data of this PhoneNumber.  # noqa: E501
        :type data: str
        """

        self._data = data

    @property
    def primary(self):
        """Gets the primary of this PhoneNumber.  # noqa: E501

        When `true`, identifies the phone number as the primary number on an account.  # noqa: E501

        :return: The primary of this PhoneNumber.  # noqa: E501
        :rtype: bool
        """
        return self._primary

    @primary.setter
    def primary(self, primary):
        """Sets the primary of this PhoneNumber.

        When `true`, identifies the phone number as the primary number on an account.  # noqa: E501

        :param primary: The primary of this PhoneNumber.  # noqa: E501
        :type primary: bool
        """

        self._primary = primary

    @property
    def type(self):
        """Gets the type of this PhoneNumber.  # noqa: E501

        The type of phone number.  # noqa: E501

        :return: The type of this PhoneNumber.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PhoneNumber.

        The type of phone number.  # noqa: E501

        :param type: The type of this PhoneNumber.  # noqa: E501
        :type type: str
        """
        allowed_values = [None,"home", "work", "office", "mobile", "mobile1", "other"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneNumber):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneNumber):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class MFA(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'question_rounds': 'float',
        'questions_per_round': 'float',
        'selection_rounds': 'float',
        'selections_per_question': 'float'
    }

    attribute_map = {
        'type': 'type',
        'question_rounds': 'question_rounds',
        'questions_per_round': 'questions_per_round',
        'selection_rounds': 'selection_rounds',
        'selections_per_question': 'selections_per_question'
    }

    def __init__(self, type=None, question_rounds=None, questions_per_round=None, selection_rounds=None, selections_per_question=None, local_vars_configuration=None):  # noqa: E501
        """MFA - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._question_rounds = None
        self._questions_per_round = None
        self._selection_rounds = None
        self._selections_per_question = None
        self.discriminator = None

        self.type = type
        if question_rounds is not None:
            self.question_rounds = question_rounds
        if questions_per_round is not None:
            self.questions_per_round = questions_per_round
        if selection_rounds is not None:
            self.selection_rounds = selection_rounds
        if selections_per_question is not None:
            self.selections_per_question = selections_per_question

    @property
    def type(self):
        """Gets the type of this MFA.  # noqa: E501

        Possible values are `device`, `selections`, or `questions`.  If value is `device`, the MFA answer is `1234`.  If value is `selections`, the MFA answer is always the first option.  If value is `questions`, the MFA answer is  `answer_<i>_<j>` for the j-th question in the i-th round, starting from 0. For example, the answer to the first question in the second round is `answer_1_0`.  # noqa: E501

        :return: The type of this MFA.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this MFA.

        Possible values are `device`, `selections`, or `questions`.  If value is `device`, the MFA answer is `1234`.  If value is `selections`, the MFA answer is always the first option.  If value is `questions`, the MFA answer is  `answer_<i>_<j>` for the j-th question in the i-th round, starting from 0. For example, the answer to the first question in the second round is `answer_1_0`.  # noqa: E501

        :param type: The type of this MFA.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def question_rounds(self):
        """Gets the question_rounds of this MFA.  # noqa: E501

        Number of rounds of questions. Required if value of `type` is `questions`.   # noqa: E501

        :return: The question_rounds of this MFA.  # noqa: E501
        :rtype: float
        """
        return self._question_rounds

    @question_rounds.setter
    def question_rounds(self, question_rounds):
        """Sets the question_rounds of this MFA.

        Number of rounds of questions. Required if value of `type` is `questions`.   # noqa: E501

        :param question_rounds: The question_rounds of this MFA.  # noqa: E501
        :type question_rounds: float
        """

        self._question_rounds = question_rounds

    @property
    def questions_per_round(self):
        """Gets the questions_per_round of this MFA.  # noqa: E501

        Number of questions per round. Required if value of `type` is `questions`. If value of type is `selections`, default value is 2.  # noqa: E501

        :return: The questions_per_round of this MFA.  # noqa: E501
        :rtype: float
        """
        return self._questions_per_round

    @questions_per_round.setter
    def questions_per_round(self, questions_per_round):
        """Sets the questions_per_round of this MFA.

        Number of questions per round. Required if value of `type` is `questions`. If value of type is `selections`, default value is 2.  # noqa: E501

        :param questions_per_round: The questions_per_round of this MFA.  # noqa: E501
        :type questions_per_round: float
        """

        self._questions_per_round = questions_per_round

    @property
    def selection_rounds(self):
        """Gets the selection_rounds of this MFA.  # noqa: E501

        Number of rounds of selections, used if `type` is `selections`. Defaults to 1.  # noqa: E501

        :return: The selection_rounds of this MFA.  # noqa: E501
        :rtype: float
        """
        return self._selection_rounds

    @selection_rounds.setter
    def selection_rounds(self, selection_rounds):
        """Sets the selection_rounds of this MFA.

        Number of rounds of selections, used if `type` is `selections`. Defaults to 1.  # noqa: E501

        :param selection_rounds: The selection_rounds of this MFA.  # noqa: E501
        :type selection_rounds: float
        """

        self._selection_rounds = selection_rounds

    @property
    def selections_per_question(self):
        """Gets the selections_per_question of this MFA.  # noqa: E501

        Number of available answers per question, used if `type` is `selection`. Defaults to 2.   # noqa: E501

        :return: The selections_per_question of this MFA.  # noqa: E501
        :rtype: float
        """
        return self._selections_per_question

    @selections_per_question.setter
    def selections_per_question(self, selections_per_question):
        """Sets the selections_per_question of this MFA.

        Number of available answers per question, used if `type` is `selection`. Defaults to 2.   # noqa: E501

        :param selections_per_question: The selections_per_question of this MFA.  # noqa: E501
        :type selections_per_question: float
        """

        self._selections_per_question = selections_per_question

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MFA):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MFA):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class Error(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'error_type': 'str',
        'error_code': 'str',
        'error_message': 'str',
        'display_message': 'str',
        'request_id': 'str',
        'causes': 'list[object]',
        'status': 'float',
        'documentation_url': 'str',
        'suggested_action': 'str'
    }

    attribute_map = {
        'error_type': 'error_type',
        'error_code': 'error_code',
        'error_message': 'error_message',
        'display_message': 'display_message',
        'request_id': 'request_id',
        'causes': 'causes',
        'status': 'status',
        'documentation_url': 'documentation_url',
        'suggested_action': 'suggested_action'
    }

    def __init__(self, error_type=None, error_code=None, error_message=None, display_message=None, request_id=None, causes=None, status=None, documentation_url=None, suggested_action=None, local_vars_configuration=None):  # noqa: E501
        """Error - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._error_type = None
        self._error_code = None
        self._error_message = None
        self._display_message = None
        self._request_id = None
        self._causes = None
        self._status = None
        self._documentation_url = None
        self._suggested_action = None
        self.discriminator = None

        if error_type is not None:
            self.error_type = error_type
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message
        self.display_message = display_message
        self.request_id = request_id
        if causes is not None:
            self.causes = causes
        self.status = status
        self.documentation_url = documentation_url
        self.suggested_action = suggested_action

    @property
    def error_type(self):
        """Gets the error_type of this Error.  # noqa: E501

        A broad categorization of the error. Safe for programatic use.  # noqa: E501

        :return: The error_type of this Error.  # noqa: E501
        :rtype: str
        """
        return self._error_type

    @error_type.setter
    def error_type(self, error_type):
        """Sets the error_type of this Error.

        A broad categorization of the error. Safe for programatic use.  # noqa: E501

        :param error_type: The error_type of this Error.  # noqa: E501
        :type error_type: str
        """
        allowed_values = ["INVALID_REQUEST", "INVALID_INPUT", "INSTITUTION_ERROR", "RATE_LIMIT_EXCEEDED", "API_ERROR", "ITEM_ERROR", "ASSET_REPORT_ERROR", "RECAPTCHA_ERROR", "OAUTH_ERROR", "PAYMENT_ERROR", "BANK_TRANSFER_ERROR"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and error_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `error_type` ({0}), must be one of {1}"  # noqa: E501
                .format(error_type, allowed_values)
            )

        self._error_type = error_type

    @property
    def error_code(self):
        """Gets the error_code of this Error.  # noqa: E501

        The particular error code. Safe for programmatic use.  # noqa: E501

        :return: The error_code of this Error.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this Error.

        The particular error code. Safe for programmatic use.  # noqa: E501

        :param error_code: The error_code of this Error.  # noqa: E501
        :type error_code: str
        """

        self._error_code = error_code

    @property
    def error_message(self):
        """Gets the error_message of this Error.  # noqa: E501

        A developer-friendly representation of the error code. This may change over time and is not safe for programmatic use.  # noqa: E501

        :return: The error_message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this Error.

        A developer-friendly representation of the error code. This may change over time and is not safe for programmatic use.  # noqa: E501

        :param error_message: The error_message of this Error.  # noqa: E501
        :type error_message: str
        """

        self._error_message = error_message

    @property
    def display_message(self):
        """Gets the display_message of this Error.  # noqa: E501

        A user-friendly representation of the error code. `null` if the error is not related to user action.  This may change over time and is not safe for programmatic use.  # noqa: E501

        :return: The display_message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._display_message

    @display_message.setter
    def display_message(self, display_message):
        """Sets the display_message of this Error.

        A user-friendly representation of the error code. `null` if the error is not related to user action.  This may change over time and is not safe for programmatic use.  # noqa: E501

        :param display_message: The display_message of this Error.  # noqa: E501
        :type display_message: str
        """

        self._display_message = display_message

    @property
    def request_id(self):
        """Gets the request_id of this Error.  # noqa: E501

        A unique identifying the request, to be used for troubleshooting purposes. This field will be omitted in errors provided by webhooks.  # noqa: E501

        :return: The request_id of this Error.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this Error.

        A unique identifying the request, to be used for troubleshooting purposes. This field will be omitted in errors provided by webhooks.  # noqa: E501

        :param request_id: The request_id of this Error.  # noqa: E501
        :type request_id: str
        """

        self._request_id = request_id

    @property
    def causes(self):
        """Gets the causes of this Error.  # noqa: E501

        In the Assets product, a request can pertain to more than one Item. If an error is returned for such a request, `causes` will return an array of errors containing a breakdown of these errors on the individual Item level, if any can be identified.  `causes` will only be provided for the `error_type` `ASSET_REPORT_ERROR`.  # noqa: E501

        :return: The causes of this Error.  # noqa: E501
        :rtype: list[object]
        """
        return self._causes

    @causes.setter
    def causes(self, causes):
        """Sets the causes of this Error.

        In the Assets product, a request can pertain to more than one Item. If an error is returned for such a request, `causes` will return an array of errors containing a breakdown of these errors on the individual Item level, if any can be identified.  `causes` will only be provided for the `error_type` `ASSET_REPORT_ERROR`.  # noqa: E501

        :param causes: The causes of this Error.  # noqa: E501
        :type causes: list[object]
        """

        self._causes = causes

    @property
    def status(self):
        """Gets the status of this Error.  # noqa: E501

        The HTTP status code associated with the error. This will only be returned in the response body when the error information is provided via a webhook.  # noqa: E501

        :return: The status of this Error.  # noqa: E501
        :rtype: float
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Error.

        The HTTP status code associated with the error. This will only be returned in the response body when the error information is provided via a webhook.  # noqa: E501

        :param status: The status of this Error.  # noqa: E501
        :type status: float
        """

        self._status = status

    @property
    def documentation_url(self):
        """Gets the documentation_url of this Error.  # noqa: E501

        The URL of a Plaid documentation page with more information about the error  # noqa: E501

        :return: The documentation_url of this Error.  # noqa: E501
        :rtype: str
        """
        return self._documentation_url

    @documentation_url.setter
    def documentation_url(self, documentation_url):
        """Sets the documentation_url of this Error.

        The URL of a Plaid documentation page with more information about the error  # noqa: E501

        :param documentation_url: The documentation_url of this Error.  # noqa: E501
        :type documentation_url: str
        """

        self._documentation_url = documentation_url

    @property
    def suggested_action(self):
        """Gets the suggested_action of this Error.  # noqa: E501

        Suggested steps for resolving the error  # noqa: E501

        :return: The suggested_action of this Error.  # noqa: E501
        :rtype: str
        """
        return self._suggested_action

    @suggested_action.setter
    def suggested_action(self, suggested_action):
        """Sets the suggested_action of this Error.

        Suggested steps for resolving the error  # noqa: E501

        :param suggested_action: The suggested_action of this Error.  # noqa: E501
        :type suggested_action: str
        """

        self._suggested_action = suggested_action

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Error):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Error):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class ExternalPaymentSchedule(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'interval': 'str',
        'interval_execution_day': 'float',
        'start_date': 'str'
    }

    attribute_map = {
        'interval': 'interval',
        'interval_execution_day': 'interval_execution_day',
        'start_date': 'start_date'
    }

    def __init__(self, interval=None, interval_execution_day=None, start_date=None, local_vars_configuration=None):  # noqa: E501
        """ExternalPaymentSchedule - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._interval = None
        self._interval_execution_day = None
        self._start_date = None
        self.discriminator = None

        if interval is not None:
            self.interval = interval
        if interval_execution_day is not None:
            self.interval_execution_day = interval_execution_day
        if start_date is not None:
            self.start_date = start_date

    @property
    def interval(self):
        """Gets the interval of this ExternalPaymentSchedule.  # noqa: E501

        The frequency interval of the payment. Valid values are `\"WEEKLY\"` or `\"MONTHLY\"`.  # noqa: E501

        :return: The interval of this ExternalPaymentSchedule.  # noqa: E501
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this ExternalPaymentSchedule.

        The frequency interval of the payment. Valid values are `\"WEEKLY\"` or `\"MONTHLY\"`.  # noqa: E501

        :param interval: The interval of this ExternalPaymentSchedule.  # noqa: E501
        :type interval: str
        """

        self._interval = interval

    @property
    def interval_execution_day(self):
        """Gets the interval_execution_day of this ExternalPaymentSchedule.  # noqa: E501

        The day of the interval on which to schedule the payment.  If the payment interval is weekly, `interval_execution_day` should be an integer from 1 (Monday) to 7 (Sunday).  If the payment interval is monthly, `interval_execution_day` should be an integer indicating which day of the month to make the payment on. Integers from 1 to 28 can be used to make a payment on that day of the month. Negative integers from -1 to -5 can be used to make a payment relative to the end of the month. To make a payment on the last day of the month, use -1; to make the payment on the second-to-last day, use -2, and so on.  # noqa: E501

        :return: The interval_execution_day of this ExternalPaymentSchedule.  # noqa: E501
        :rtype: float
        """
        return self._interval_execution_day

    @interval_execution_day.setter
    def interval_execution_day(self, interval_execution_day):
        """Sets the interval_execution_day of this ExternalPaymentSchedule.

        The day of the interval on which to schedule the payment.  If the payment interval is weekly, `interval_execution_day` should be an integer from 1 (Monday) to 7 (Sunday).  If the payment interval is monthly, `interval_execution_day` should be an integer indicating which day of the month to make the payment on. Integers from 1 to 28 can be used to make a payment on that day of the month. Negative integers from -1 to -5 can be used to make a payment relative to the end of the month. To make a payment on the last day of the month, use -1; to make the payment on the second-to-last day, use -2, and so on.  # noqa: E501

        :param interval_execution_day: The interval_execution_day of this ExternalPaymentSchedule.  # noqa: E501
        :type interval_execution_day: float
        """

        self._interval_execution_day = interval_execution_day

    @property
    def start_date(self):
        """Gets the start_date of this ExternalPaymentSchedule.  # noqa: E501

        A date in ISO 8601 format (YYYY-MM-DD). Standing order payments will begin on the first `interval_execution_day` on or after the `start_date`.  If the first `interval_execution_day` on or after the start date is also the same day that `/payment_initiation/payment/create` was called, the bank *may* make the first payment on that day, but it is not guaranteed to do so.  It is not possible to specify an end date for a standing order payment.  To end or modify a standing order payment, the end user should contact their bank.  # noqa: E501

        :return: The start_date of this ExternalPaymentSchedule.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ExternalPaymentSchedule.

        A date in ISO 8601 format (YYYY-MM-DD). Standing order payments will begin on the first `interval_execution_day` on or after the `start_date`.  If the first `interval_execution_day` on or after the start date is also the same day that `/payment_initiation/payment/create` was called, the bank *may* make the first payment on that day, but it is not guaranteed to do so.  It is not possible to specify an end date for a standing order payment.  To end or modify a standing order payment, the end user should contact their bank.  # noqa: E501

        :param start_date: The start_date of this ExternalPaymentSchedule.  # noqa: E501
        :type start_date: str
        """

        self._start_date = start_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExternalPaymentSchedule):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExternalPaymentSchedule):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class LinkTokenCreateRequestUser(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'client_user_id': 'str',
        'legal_name': 'str',
        'phone_number': 'str',
        'phone_number_verified_time': 'str',
        'email_address': 'str',
        'email_address_verified_time': 'str'
    }

    attribute_map = {
        'client_user_id': 'client_user_id',
        'legal_name': 'legal_name',
        'phone_number': 'phone_number',
        'phone_number_verified_time': 'phone_number_verified_time',
        'email_address': 'email_address',
        'email_address_verified_time': 'email_address_verified_time'
    }

    def __init__(self, client_user_id=None, legal_name=None, phone_number=None, phone_number_verified_time=None, email_address=None, email_address_verified_time=None, local_vars_configuration=None):  # noqa: E501
        """LinkTokenCreateRequestUser - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._client_user_id = None
        self._legal_name = None
        self._phone_number = None
        self._phone_number_verified_time = None
        self._email_address = None
        self._email_address_verified_time = None
        self.discriminator = None

        self.client_user_id = client_user_id
        if legal_name is not None:
            self.legal_name = legal_name
        if phone_number is not None:
            self.phone_number = phone_number
        if phone_number_verified_time is not None:
            self.phone_number_verified_time = phone_number_verified_time
        if email_address is not None:
            self.email_address = email_address
        if email_address_verified_time is not None:
            self.email_address_verified_time = email_address_verified_time

    @property
    def client_user_id(self):
        """Gets the client_user_id of this LinkTokenCreateRequestUser.  # noqa: E501

        A unique ID representing the end user. Typically this will be a user ID number from your application. Personally identifiable information, such as an email address or phone number, should not be used in the `client_user_id`.  # noqa: E501

        :return: The client_user_id of this LinkTokenCreateRequestUser.  # noqa: E501
        :rtype: str
        """
        return self._client_user_id

    @client_user_id.setter
    def client_user_id(self, client_user_id):
        """Sets the client_user_id of this LinkTokenCreateRequestUser.

        A unique ID representing the end user. Typically this will be a user ID number from your application. Personally identifiable information, such as an email address or phone number, should not be used in the `client_user_id`.  # noqa: E501

        :param client_user_id: The client_user_id of this LinkTokenCreateRequestUser.  # noqa: E501
        :type client_user_id: str
        """
        if self.local_vars_configuration.client_side_validation and client_user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `client_user_id`, must not be `None`")  # noqa: E501

        self._client_user_id = client_user_id

    @property
    def legal_name(self):
        """Gets the legal_name of this LinkTokenCreateRequestUser.  # noqa: E501

        The user's full legal name. This is an optional field used in the [returning user experience](/docs/link/returning-user) to associate Items to the user.  # noqa: E501

        :return: The legal_name of this LinkTokenCreateRequestUser.  # noqa: E501
        :rtype: str
        """
        return self._legal_name

    @legal_name.setter
    def legal_name(self, legal_name):
        """Sets the legal_name of this LinkTokenCreateRequestUser.

        The user's full legal name. This is an optional field used in the [returning user experience](/docs/link/returning-user) to associate Items to the user.  # noqa: E501

        :param legal_name: The legal_name of this LinkTokenCreateRequestUser.  # noqa: E501
        :type legal_name: str
        """

        self._legal_name = legal_name

    @property
    def phone_number(self):
        """Gets the phone_number of this LinkTokenCreateRequestUser.  # noqa: E501

        The user's phone number in [E.164](https://en.wikipedia.org/wiki/E.164) format. This field is optional, but required to enable the [returning user experience](/docs/link/returning-user).  # noqa: E501

        :return: The phone_number of this LinkTokenCreateRequestUser.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this LinkTokenCreateRequestUser.

        The user's phone number in [E.164](https://en.wikipedia.org/wiki/E.164) format. This field is optional, but required to enable the [returning user experience](/docs/link/returning-user).  # noqa: E501

        :param phone_number: The phone_number of this LinkTokenCreateRequestUser.  # noqa: E501
        :type phone_number: str
        """

        self._phone_number = phone_number

    @property
    def phone_number_verified_time(self):
        """Gets the phone_number_verified_time of this LinkTokenCreateRequestUser.  # noqa: E501

        The date and time the phone number was verified in ISO 8601 format (`YYYY-MM-DDThh:mm:ssZ`). This field is optional, but required to enable any [returning user experience](/docs/link/returning-user).   Only pass a verification time for a phone number that you have verified. If you have performed verification but don’t have the time, you may supply a signal value of the start of the UNIX epoch.   Example: `2020-01-01T00:00:00Z`   # noqa: E501

        :return: The phone_number_verified_time of this LinkTokenCreateRequestUser.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_verified_time

    @phone_number_verified_time.setter
    def phone_number_verified_time(self, phone_number_verified_time):
        """Sets the phone_number_verified_time of this LinkTokenCreateRequestUser.

        The date and time the phone number was verified in ISO 8601 format (`YYYY-MM-DDThh:mm:ssZ`). This field is optional, but required to enable any [returning user experience](/docs/link/returning-user).   Only pass a verification time for a phone number that you have verified. If you have performed verification but don’t have the time, you may supply a signal value of the start of the UNIX epoch.   Example: `2020-01-01T00:00:00Z`   # noqa: E501

        :param phone_number_verified_time: The phone_number_verified_time of this LinkTokenCreateRequestUser.  # noqa: E501
        :type phone_number_verified_time: str
        """

        self._phone_number_verified_time = phone_number_verified_time

    @property
    def email_address(self):
        """Gets the email_address of this LinkTokenCreateRequestUser.  # noqa: E501

        The user's email address. This field is optional, but required to enable the [pre-authenticated returning user flow](/docs/link/returning-user/#enabling-the-returning-user-experience).  # noqa: E501

        :return: The email_address of this LinkTokenCreateRequestUser.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this LinkTokenCreateRequestUser.

        The user's email address. This field is optional, but required to enable the [pre-authenticated returning user flow](/docs/link/returning-user/#enabling-the-returning-user-experience).  # noqa: E501

        :param email_address: The email_address of this LinkTokenCreateRequestUser.  # noqa: E501
        :type email_address: str
        """

        self._email_address = email_address

    @property
    def email_address_verified_time(self):
        """Gets the email_address_verified_time of this LinkTokenCreateRequestUser.  # noqa: E501

        The date and time the email address was verified in ISO 8601 format (`YYYY-MM-DDThh:mm:ssZ`). This is an optional field used in the [returning user experience](/docs/link/returning-user).   Only pass a verification time for an email address that you have verified. If you have performed verification but don’t have the time, you may supply a signal value of the start of the UNIX epoch.   Example: `2020-01-01T00:00:00Z`  # noqa: E501

        :return: The email_address_verified_time of this LinkTokenCreateRequestUser.  # noqa: E501
        :rtype: str
        """
        return self._email_address_verified_time

    @email_address_verified_time.setter
    def email_address_verified_time(self, email_address_verified_time):
        """Sets the email_address_verified_time of this LinkTokenCreateRequestUser.

        The date and time the email address was verified in ISO 8601 format (`YYYY-MM-DDThh:mm:ssZ`). This is an optional field used in the [returning user experience](/docs/link/returning-user).   Only pass a verification time for an email address that you have verified. If you have performed verification but don’t have the time, you may supply a signal value of the start of the UNIX epoch.   Example: `2020-01-01T00:00:00Z`  # noqa: E501

        :param email_address_verified_time: The email_address_verified_time of this LinkTokenCreateRequestUser.  # noqa: E501
        :type email_address_verified_time: str
        """

        self._email_address_verified_time = email_address_verified_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LinkTokenCreateRequestUser):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LinkTokenCreateRequestUser):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class ItemStatusLastWebhook(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sent_at': 'str',
        'code_sent': 'str'
    }

    attribute_map = {
        'sent_at': 'sent_at',
        'code_sent': 'code_sent'
    }

    def __init__(self, sent_at=None, code_sent=None, local_vars_configuration=None):  # noqa: E501
        """ItemStatusLastWebhook - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sent_at = None
        self._code_sent = None
        self.discriminator = None

        self.sent_at = sent_at
        self.code_sent = code_sent

    @property
    def sent_at(self):
        """Gets the sent_at of this ItemStatusLastWebhook.  # noqa: E501

        ISO 8601 timestamp of when the webhook was fired.  # noqa: E501

        :return: The sent_at of this ItemStatusLastWebhook.  # noqa: E501
        :rtype: str
        """
        return self._sent_at

    @sent_at.setter
    def sent_at(self, sent_at):
        """Sets the sent_at of this ItemStatusLastWebhook.

        ISO 8601 timestamp of when the webhook was fired.  # noqa: E501

        :param sent_at: The sent_at of this ItemStatusLastWebhook.  # noqa: E501
        :type sent_at: str
        """

        self._sent_at = sent_at

    @property
    def code_sent(self):
        """Gets the code_sent of this ItemStatusLastWebhook.  # noqa: E501

        The last webhook code sent.  # noqa: E501

        :return: The code_sent of this ItemStatusLastWebhook.  # noqa: E501
        :rtype: str
        """
        return self._code_sent

    @code_sent.setter
    def code_sent(self, code_sent):
        """Sets the code_sent of this ItemStatusLastWebhook.

        The last webhook code sent.  # noqa: E501

        :param code_sent: The code_sent of this ItemStatusLastWebhook.  # noqa: E501
        :type code_sent: str
        """

        self._code_sent = code_sent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemStatusLastWebhook):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemStatusLastWebhook):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class StandaloneAccountType(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'depository': 'str',
        'credit': 'str',
        'loan': 'str',
        'investment': 'str',
        'other': 'str'
    }

    attribute_map = {
        'depository': 'depository',
        'credit': 'credit',
        'loan': 'loan',
        'investment': 'investment',
        'other': 'other'
    }

    def __init__(self, depository=None, credit=None, loan=None, investment=None, other=None, local_vars_configuration=None):  # noqa: E501
        """StandaloneAccountType - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._depository = None
        self._credit = None
        self._loan = None
        self._investment = None
        self._other = None
        self.discriminator = None

        if depository is not None:
            self.depository = depository
        if credit is not None:
            self.credit = credit
        if loan is not None:
            self.loan = loan
        if investment is not None:
            self.investment = investment
        if other is not None:
            self.other = other

    @property
    def depository(self):
        """Gets the depository of this StandaloneAccountType.  # noqa: E501

        An account type holding cash, in which funds are deposited. Supported products for `depository` accounts are: Auth, Balance, Transactions, Identity, Payment Initiation, and Assets.  # noqa: E501

        :return: The depository of this StandaloneAccountType.  # noqa: E501
        :rtype: str
        """
        return self._depository

    @depository.setter
    def depository(self, depository):
        """Sets the depository of this StandaloneAccountType.

        An account type holding cash, in which funds are deposited. Supported products for `depository` accounts are: Auth, Balance, Transactions, Identity, Payment Initiation, and Assets.  # noqa: E501

        :param depository: The depository of this StandaloneAccountType.  # noqa: E501
        :type depository: str
        """

        self._depository = depository

    @property
    def credit(self):
        """Gets the credit of this StandaloneAccountType.  # noqa: E501

        A credit card type account. Supported products for `credit` accounts are: Balance, Transactions, Identity, and Liabilities.  # noqa: E501

        :return: The credit of this StandaloneAccountType.  # noqa: E501
        :rtype: str
        """
        return self._credit

    @credit.setter
    def credit(self, credit):
        """Sets the credit of this StandaloneAccountType.

        A credit card type account. Supported products for `credit` accounts are: Balance, Transactions, Identity, and Liabilities.  # noqa: E501

        :param credit: The credit of this StandaloneAccountType.  # noqa: E501
        :type credit: str
        """

        self._credit = credit

    @property
    def loan(self):
        """Gets the loan of this StandaloneAccountType.  # noqa: E501

        A loan type account. Supported products for `loan` accounts are: Balance, Liabilities, and Transactions.  # noqa: E501

        :return: The loan of this StandaloneAccountType.  # noqa: E501
        :rtype: str
        """
        return self._loan

    @loan.setter
    def loan(self, loan):
        """Sets the loan of this StandaloneAccountType.

        A loan type account. Supported products for `loan` accounts are: Balance, Liabilities, and Transactions.  # noqa: E501

        :param loan: The loan of this StandaloneAccountType.  # noqa: E501
        :type loan: str
        """

        self._loan = loan

    @property
    def investment(self):
        """Gets the investment of this StandaloneAccountType.  # noqa: E501

        An investment account. Supported products for `investment` accounts are: Balance and Investments.  # noqa: E501

        :return: The investment of this StandaloneAccountType.  # noqa: E501
        :rtype: str
        """
        return self._investment

    @investment.setter
    def investment(self, investment):
        """Sets the investment of this StandaloneAccountType.

        An investment account. Supported products for `investment` accounts are: Balance and Investments.  # noqa: E501

        :param investment: The investment of this StandaloneAccountType.  # noqa: E501
        :type investment: str
        """

        self._investment = investment

    @property
    def other(self):
        """Gets the other of this StandaloneAccountType.  # noqa: E501

        Other or unknown account type. Supported products for `other` accounts are: Balance, Transactions, Identity, and Assets.  # noqa: E501

        :return: The other of this StandaloneAccountType.  # noqa: E501
        :rtype: str
        """
        return self._other

    @other.setter
    def other(self, other):
        """Sets the other of this StandaloneAccountType.

        Other or unknown account type. Supported products for `other` accounts are: Balance, Transactions, Identity, and Assets.  # noqa: E501

        :param other: The other of this StandaloneAccountType.  # noqa: E501
        :type other: str
        """

        self._other = other

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StandaloneAccountType):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StandaloneAccountType):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class LinkTokenGetResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'link_token': 'str',
        'created_at': 'str',
        'expiration': 'str',
        'metadata': 'LinkTokenGetMetadataResponse',
        'request_id': 'str'
    }

    attribute_map = {
        'link_token': 'link_token',
        'created_at': 'created_at',
        'expiration': 'expiration',
        'metadata': 'metadata',
        'request_id': 'request_id'
    }

    def __init__(self, link_token=None, created_at=None, expiration=None, metadata=None, request_id=None, local_vars_configuration=None):  # noqa: E501
        """LinkTokenGetResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._link_token = None
        self._created_at = None
        self._expiration = None
        self._metadata = None
        self._request_id = None
        self.discriminator = None

        if link_token is not None:
            self.link_token = link_token
        if created_at is not None:
            self.created_at = created_at
        if expiration is not None:
            self.expiration = expiration
        if metadata is not None:
            self.metadata = metadata
        if request_id is not None:
            self.request_id = request_id

    @property
    def link_token(self):
        """Gets the link_token of this LinkTokenGetResponse.  # noqa: E501

        A `link_token`, which can be supplied to Link in order to initialize it and receive a `public_token`, which can be exchanged for an `access_token`.  # noqa: E501

        :return: The link_token of this LinkTokenGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._link_token

    @link_token.setter
    def link_token(self, link_token):
        """Sets the link_token of this LinkTokenGetResponse.

        A `link_token`, which can be supplied to Link in order to initialize it and receive a `public_token`, which can be exchanged for an `access_token`.  # noqa: E501

        :param link_token: The link_token of this LinkTokenGetResponse.  # noqa: E501
        :type link_token: str
        """

        self._link_token = link_token

    @property
    def created_at(self):
        """Gets the created_at of this LinkTokenGetResponse.  # noqa: E501

        The creation date for the `link_token`, in ISO 8601 format.  # noqa: E501

        :return: The created_at of this LinkTokenGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this LinkTokenGetResponse.

        The creation date for the `link_token`, in ISO 8601 format.  # noqa: E501

        :param created_at: The created_at of this LinkTokenGetResponse.  # noqa: E501
        :type created_at: str
        """

        self._created_at = created_at

    @property
    def expiration(self):
        """Gets the expiration of this LinkTokenGetResponse.  # noqa: E501

        The expiration date for the `link_token`, in ISO 8601 format.  # noqa: E501

        :return: The expiration of this LinkTokenGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this LinkTokenGetResponse.

        The expiration date for the `link_token`, in ISO 8601 format.  # noqa: E501

        :param expiration: The expiration of this LinkTokenGetResponse.  # noqa: E501
        :type expiration: str
        """

        self._expiration = expiration

    @property
    def metadata(self):
        """Gets the metadata of this LinkTokenGetResponse.  # noqa: E501


        :return: The metadata of this LinkTokenGetResponse.  # noqa: E501
        :rtype: LinkTokenGetMetadataResponse
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this LinkTokenGetResponse.


        :param metadata: The metadata of this LinkTokenGetResponse.  # noqa: E501
        :type metadata: LinkTokenGetMetadataResponse
        """

        self._metadata = metadata

    @property
    def request_id(self):
        """Gets the request_id of this LinkTokenGetResponse.  # noqa: E501

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :return: The request_id of this LinkTokenGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this LinkTokenGetResponse.

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :param request_id: The request_id of this LinkTokenGetResponse.  # noqa: E501
        :type request_id: str
        """

        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LinkTokenGetResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LinkTokenGetResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class APR(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'apr_percentage': 'float',
        'apr_type': 'str',
        'balance_subject_to_apr': 'float',
        'interest_charge_amount': 'float'
    }

    attribute_map = {
        'apr_percentage': 'apr_percentage',
        'apr_type': 'apr_type',
        'balance_subject_to_apr': 'balance_subject_to_apr',
        'interest_charge_amount': 'interest_charge_amount'
    }

    def __init__(self, apr_percentage=None, apr_type=None, balance_subject_to_apr=None, interest_charge_amount=None, local_vars_configuration=None):  # noqa: E501
        """APR - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._apr_percentage = None
        self._apr_type = None
        self._balance_subject_to_apr = None
        self._interest_charge_amount = None
        self.discriminator = None

        if apr_percentage is not None:
            self.apr_percentage = apr_percentage
        if apr_type is not None:
            self.apr_type = apr_type
        self.balance_subject_to_apr = balance_subject_to_apr
        self.interest_charge_amount = interest_charge_amount

    @property
    def apr_percentage(self):
        """Gets the apr_percentage of this APR.  # noqa: E501

        Annual Percentage Rate applied.   # noqa: E501

        :return: The apr_percentage of this APR.  # noqa: E501
        :rtype: float
        """
        return self._apr_percentage

    @apr_percentage.setter
    def apr_percentage(self, apr_percentage):
        """Sets the apr_percentage of this APR.

        Annual Percentage Rate applied.   # noqa: E501

        :param apr_percentage: The apr_percentage of this APR.  # noqa: E501
        :type apr_percentage: float
        """

        self._apr_percentage = apr_percentage

    @property
    def apr_type(self):
        """Gets the apr_type of this APR.  # noqa: E501

        The type of balance to which the APR applies.  # noqa: E501

        :return: The apr_type of this APR.  # noqa: E501
        :rtype: str
        """
        return self._apr_type

    @apr_type.setter
    def apr_type(self, apr_type):
        """Sets the apr_type of this APR.

        The type of balance to which the APR applies.  # noqa: E501

        :param apr_type: The apr_type of this APR.  # noqa: E501
        :type apr_type: str
        """
        allowed_values = ["balance_transfer_apr", "cash_apr", "purchase_apr", "special"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and apr_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `apr_type` ({0}), must be one of {1}"  # noqa: E501
                .format(apr_type, allowed_values)
            )

        self._apr_type = apr_type

    @property
    def balance_subject_to_apr(self):
        """Gets the balance_subject_to_apr of this APR.  # noqa: E501

        Amount of money that is subjected to the APR if a balance was carried beyond payment due date. How it is calculated can vary by card issuer. It is often calculated as an average daily balance.  # noqa: E501

        :return: The balance_subject_to_apr of this APR.  # noqa: E501
        :rtype: float
        """
        return self._balance_subject_to_apr

    @balance_subject_to_apr.setter
    def balance_subject_to_apr(self, balance_subject_to_apr):
        """Sets the balance_subject_to_apr of this APR.

        Amount of money that is subjected to the APR if a balance was carried beyond payment due date. How it is calculated can vary by card issuer. It is often calculated as an average daily balance.  # noqa: E501

        :param balance_subject_to_apr: The balance_subject_to_apr of this APR.  # noqa: E501
        :type balance_subject_to_apr: float
        """

        self._balance_subject_to_apr = balance_subject_to_apr

    @property
    def interest_charge_amount(self):
        """Gets the interest_charge_amount of this APR.  # noqa: E501

        Amount of money charged due to interest from last statement.  # noqa: E501

        :return: The interest_charge_amount of this APR.  # noqa: E501
        :rtype: float
        """
        return self._interest_charge_amount

    @interest_charge_amount.setter
    def interest_charge_amount(self, interest_charge_amount):
        """Sets the interest_charge_amount of this APR.

        Amount of money charged due to interest from last statement.  # noqa: E501

        :param interest_charge_amount: The interest_charge_amount of this APR.  # noqa: E501
        :type interest_charge_amount: float
        """

        self._interest_charge_amount = interest_charge_amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, APR):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, APR):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class PaymentInitiationPaymentGetResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'payment_id': 'str',
        'request_id': 'str',
        'amount': 'PaymentAmount',
        'status': 'str',
        'recipient_id': 'str',
        'reference': 'str',
        'last_status_update': 'str',
        'schedule': 'ExternalPaymentSchedule'
    }

    attribute_map = {
        'payment_id': 'payment_id',
        'request_id': 'request_id',
        'amount': 'amount',
        'status': 'status',
        'recipient_id': 'recipient_id',
        'reference': 'reference',
        'last_status_update': 'last_status_update',
        'schedule': 'schedule'
    }

    def __init__(self, payment_id=None, request_id=None, amount=None, status=None, recipient_id=None, reference=None, last_status_update=None, schedule=None, local_vars_configuration=None):  # noqa: E501
        """PaymentInitiationPaymentGetResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._payment_id = None
        self._request_id = None
        self._amount = None
        self._status = None
        self._recipient_id = None
        self._reference = None
        self._last_status_update = None
        self._schedule = None
        self.discriminator = None

        if payment_id is not None:
            self.payment_id = payment_id
        if request_id is not None:
            self.request_id = request_id
        if amount is not None:
            self.amount = amount
        if status is not None:
            self.status = status
        if recipient_id is not None:
            self.recipient_id = recipient_id
        if reference is not None:
            self.reference = reference
        if last_status_update is not None:
            self.last_status_update = last_status_update
        self.schedule = schedule

    @property
    def payment_id(self):
        """Gets the payment_id of this PaymentInitiationPaymentGetResponse.  # noqa: E501

        The ID of the payment. Like all Plaid identifiers, the `payment_id` is case sensitive.  # noqa: E501

        :return: The payment_id of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._payment_id

    @payment_id.setter
    def payment_id(self, payment_id):
        """Sets the payment_id of this PaymentInitiationPaymentGetResponse.

        The ID of the payment. Like all Plaid identifiers, the `payment_id` is case sensitive.  # noqa: E501

        :param payment_id: The payment_id of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :type payment_id: str
        """

        self._payment_id = payment_id

    @property
    def request_id(self):
        """Gets the request_id of this PaymentInitiationPaymentGetResponse.  # noqa: E501

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :return: The request_id of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this PaymentInitiationPaymentGetResponse.

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :param request_id: The request_id of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :type request_id: str
        """

        self._request_id = request_id

    @property
    def amount(self):
        """Gets the amount of this PaymentInitiationPaymentGetResponse.  # noqa: E501


        :return: The amount of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :rtype: PaymentAmount
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PaymentInitiationPaymentGetResponse.


        :param amount: The amount of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :type amount: PaymentAmount
        """

        self._amount = amount

    @property
    def status(self):
        """Gets the status of this PaymentInitiationPaymentGetResponse.  # noqa: E501

        The status of the payment.  `PAYMENT_STATUS_INPUT_NEEDED`: This is the initial state of all payments. It indicates that the payment is waiting on user input to continue processing. A payment may re-enter this state later on if further input is needed.  `PAYMENT_STATUS_PROCESSING`: The payment is currently being processed. The payment will automatically exit this state when processing is complete.  `PAYMENT_STATUS_INITIATED`: The payment has been successfully initiated and is considered complete.  `PAYMENT_STATUS_COMPLETED`: Indicates that the standing order has been successfully established. This state is only used for standing orders.  `PAYMENT_STATUS_INSUFFICIENT_FUNDS`: The payment has failed due to insufficient funds.  `PAYMENT_STATUS_FAILED`: The payment has failed to be initiated. This error is retryable once the root cause is resolved.  `PAYMENT_STATUS_BLOCKED`: The payment has been blocked. This is a retryable error.  `PAYMENT_STATUS_UNKNOWN`: The payment status is unknown.  # noqa: E501

        :return: The status of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PaymentInitiationPaymentGetResponse.

        The status of the payment.  `PAYMENT_STATUS_INPUT_NEEDED`: This is the initial state of all payments. It indicates that the payment is waiting on user input to continue processing. A payment may re-enter this state later on if further input is needed.  `PAYMENT_STATUS_PROCESSING`: The payment is currently being processed. The payment will automatically exit this state when processing is complete.  `PAYMENT_STATUS_INITIATED`: The payment has been successfully initiated and is considered complete.  `PAYMENT_STATUS_COMPLETED`: Indicates that the standing order has been successfully established. This state is only used for standing orders.  `PAYMENT_STATUS_INSUFFICIENT_FUNDS`: The payment has failed due to insufficient funds.  `PAYMENT_STATUS_FAILED`: The payment has failed to be initiated. This error is retryable once the root cause is resolved.  `PAYMENT_STATUS_BLOCKED`: The payment has been blocked. This is a retryable error.  `PAYMENT_STATUS_UNKNOWN`: The payment status is unknown.  # noqa: E501

        :param status: The status of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :type status: str
        """
        allowed_values = ["PAYMENT_STATUS_INPUT_NEEDED", "PAYMENT_STATUS_PROCESSING", "PAYMENT_STATUS_INITIATED", "PAYMENT_STATUS_COMPLETED", "PAYMENT_STATUS_INSUFFICIENT_FUNDS", "PAYMENT_STATUS_FAILED", "PAYMENT_STATUS_BLOCKED", "PAYMENT_STATUS_UNKNOWN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def recipient_id(self):
        """Gets the recipient_id of this PaymentInitiationPaymentGetResponse.  # noqa: E501

        The ID of the recipient  # noqa: E501

        :return: The recipient_id of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._recipient_id

    @recipient_id.setter
    def recipient_id(self, recipient_id):
        """Sets the recipient_id of this PaymentInitiationPaymentGetResponse.

        The ID of the recipient  # noqa: E501

        :param recipient_id: The recipient_id of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :type recipient_id: str
        """

        self._recipient_id = recipient_id

    @property
    def reference(self):
        """Gets the reference of this PaymentInitiationPaymentGetResponse.  # noqa: E501

        A reference for the payment.  # noqa: E501

        :return: The reference of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this PaymentInitiationPaymentGetResponse.

        A reference for the payment.  # noqa: E501

        :param reference: The reference of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :type reference: str
        """

        self._reference = reference

    @property
    def last_status_update(self):
        """Gets the last_status_update of this PaymentInitiationPaymentGetResponse.  # noqa: E501

        The date and time of the last time the `status` was updated, in IS0 8601 format  # noqa: E501

        :return: The last_status_update of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._last_status_update

    @last_status_update.setter
    def last_status_update(self, last_status_update):
        """Sets the last_status_update of this PaymentInitiationPaymentGetResponse.

        The date and time of the last time the `status` was updated, in IS0 8601 format  # noqa: E501

        :param last_status_update: The last_status_update of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :type last_status_update: str
        """

        self._last_status_update = last_status_update

    @property
    def schedule(self):
        """Gets the schedule of this PaymentInitiationPaymentGetResponse.  # noqa: E501


        :return: The schedule of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :rtype: ExternalPaymentSchedule
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """Sets the schedule of this PaymentInitiationPaymentGetResponse.


        :param schedule: The schedule of this PaymentInitiationPaymentGetResponse.  # noqa: E501
        :type schedule: ExternalPaymentSchedule
        """

        self._schedule = schedule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentInitiationPaymentGetResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PaymentInitiationPaymentGetResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class InstitutionStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'item_logins': 'ProductStatus',
        'transactions_updates': 'ProductStatus',
        'auth': 'ProductStatus',
        'balance': 'ProductStatus',
        'identity': 'ProductStatus'
    }

    attribute_map = {
        'item_logins': 'item_logins',
        'transactions_updates': 'transactions_updates',
        'auth': 'auth',
        'balance': 'balance',
        'identity': 'identity'
    }

    def __init__(self, item_logins=None, transactions_updates=None, auth=None, balance=None, identity=None, local_vars_configuration=None):  # noqa: E501
        """InstitutionStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._item_logins = None
        self._transactions_updates = None
        self._auth = None
        self._balance = None
        self._identity = None
        self.discriminator = None

        if item_logins is not None:
            self.item_logins = item_logins
        if transactions_updates is not None:
            self.transactions_updates = transactions_updates
        if auth is not None:
            self.auth = auth
        if balance is not None:
            self.balance = balance
        if identity is not None:
            self.identity = identity

    @property
    def item_logins(self):
        """Gets the item_logins of this InstitutionStatus.  # noqa: E501


        :return: The item_logins of this InstitutionStatus.  # noqa: E501
        :rtype: ProductStatus
        """
        return self._item_logins

    @item_logins.setter
    def item_logins(self, item_logins):
        """Sets the item_logins of this InstitutionStatus.


        :param item_logins: The item_logins of this InstitutionStatus.  # noqa: E501
        :type item_logins: ProductStatus
        """

        self._item_logins = item_logins

    @property
    def transactions_updates(self):
        """Gets the transactions_updates of this InstitutionStatus.  # noqa: E501


        :return: The transactions_updates of this InstitutionStatus.  # noqa: E501
        :rtype: ProductStatus
        """
        return self._transactions_updates

    @transactions_updates.setter
    def transactions_updates(self, transactions_updates):
        """Sets the transactions_updates of this InstitutionStatus.


        :param transactions_updates: The transactions_updates of this InstitutionStatus.  # noqa: E501
        :type transactions_updates: ProductStatus
        """

        self._transactions_updates = transactions_updates

    @property
    def auth(self):
        """Gets the auth of this InstitutionStatus.  # noqa: E501


        :return: The auth of this InstitutionStatus.  # noqa: E501
        :rtype: ProductStatus
        """
        return self._auth

    @auth.setter
    def auth(self, auth):
        """Sets the auth of this InstitutionStatus.


        :param auth: The auth of this InstitutionStatus.  # noqa: E501
        :type auth: ProductStatus
        """

        self._auth = auth

    @property
    def balance(self):
        """Gets the balance of this InstitutionStatus.  # noqa: E501


        :return: The balance of this InstitutionStatus.  # noqa: E501
        :rtype: ProductStatus
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this InstitutionStatus.


        :param balance: The balance of this InstitutionStatus.  # noqa: E501
        :type balance: ProductStatus
        """

        self._balance = balance

    @property
    def identity(self):
        """Gets the identity of this InstitutionStatus.  # noqa: E501


        :return: The identity of this InstitutionStatus.  # noqa: E501
        :rtype: ProductStatus
        """
        return self._identity

    @identity.setter
    def identity(self, identity):
        """Sets the identity of this InstitutionStatus.


        :param identity: The identity of this InstitutionStatus.  # noqa: E501
        :type identity: ProductStatus
        """

        self._identity = identity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstitutionStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InstitutionStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from plaid.generated_plaid.api_client import ApiClient
from plaid.generated_plaid.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DefaultApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_payment_token(self, payment_initiation_payment_token_create_request, **kwargs):  # noqa: E501
        """Create payment token  # noqa: E501

        The `/payment_initiation/payment/token/create` endpoint has been deprecated. New Plaid customers will be unable to use this endpoint, and existing customers are encouraged to migrate to the newer, `link_token`-based flow. The recommended flow is to provide the `payment_id` to `/link/token/create`, which returns a `link_token` used to initialize Link.  The `/payment_initiation/payment/token/create` is used to create a `payment_token`, which can then be used in Link initialization to enter a payment initiation flow. You can only use a `payment_token` once. If this attempt fails, the end user aborts the flow, or the token expires, you will need to create a new payment token. Creating a new payment token does not require end user input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_payment_token(payment_initiation_payment_token_create_request, async_req=True)
        >>> result = thread.get()

        :param payment_initiation_payment_token_create_request: (required)
        :type payment_initiation_payment_token_create_request: PaymentInitiationPaymentTokenCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PaymentInitiationPaymentTokenCreateResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.create_payment_token_with_http_info(payment_initiation_payment_token_create_request, **kwargs)  # noqa: E501

    def create_payment_token_with_http_info(self, payment_initiation_payment_token_create_request, **kwargs):  # noqa: E501
        """Create payment token  # noqa: E501

        The `/payment_initiation/payment/token/create` endpoint has been deprecated. New Plaid customers will be unable to use this endpoint, and existing customers are encouraged to migrate to the newer, `link_token`-based flow. The recommended flow is to provide the `payment_id` to `/link/token/create`, which returns a `link_token` used to initialize Link.  The `/payment_initiation/payment/token/create` is used to create a `payment_token`, which can then be used in Link initialization to enter a payment initiation flow. You can only use a `payment_token` once. If this attempt fails, the end user aborts the flow, or the token expires, you will need to create a new payment token. Creating a new payment token does not require end user input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_payment_token_with_http_info(payment_initiation_payment_token_create_request, async_req=True)
        >>> result = thread.get()

        :param payment_initiation_payment_token_create_request: (required)
        :type payment_initiation_payment_token_create_request: PaymentInitiationPaymentTokenCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PaymentInitiationPaymentTokenCreateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'payment_initiation_payment_token_create_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_payment_token" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'payment_initiation_payment_token_create_request' is set
        if self.api_client.client_side_validation and ('payment_initiation_payment_token_create_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['payment_initiation_payment_token_create_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `payment_initiation_payment_token_create_request` when calling `create_payment_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'payment_initiation_payment_token_create_request' in local_var_params:
            body_params = local_var_params['payment_initiation_payment_token_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/payment_initiation/payment/token/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaymentInitiationPaymentTokenCreateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def item_create_public_token(self, item_public_token_create_request, **kwargs):  # noqa: E501
        """Create public token  # noqa: E501

        Note: As of July 2020, the `/item/public_token/create` endpoint is deprecated. Instead, use `/link/token/create` with an `access_token` to create a Link token for use with [update mode](/docs/link/update-mode).  If you need your user to take action to restore or resolve an error associated with an Item, generate a public token with the `/item/public_token/create` endpoint and then initialize Link with that `public_token`.  A `public_token` is one-time use and expires after 30 minutes. You use a `public_token` to initialize Link in [update mode](/docs/link/update-mode) for a particular Item. You can generate a `public_token` for an Item even if you did not use Link to create the Item originally.  The `/item/public_token/create` endpoint is **not** used to create your initial `public_token`. If you have not already received an `access_token` for a specific Item, use Link to obtain your `public_token` instead. See the [Quickstart](/docs/quickstart) for more information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.item_create_public_token(item_public_token_create_request, async_req=True)
        >>> result = thread.get()

        :param item_public_token_create_request: (required)
        :type item_public_token_create_request: ItemPublicTokenCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ItemPublicTokenCreateResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.item_create_public_token_with_http_info(item_public_token_create_request, **kwargs)  # noqa: E501

    def item_create_public_token_with_http_info(self, item_public_token_create_request, **kwargs):  # noqa: E501
        """Create public token  # noqa: E501

        Note: As of July 2020, the `/item/public_token/create` endpoint is deprecated. Instead, use `/link/token/create` with an `access_token` to create a Link token for use with [update mode](/docs/link/update-mode).  If you need your user to take action to restore or resolve an error associated with an Item, generate a public token with the `/item/public_token/create` endpoint and then initialize Link with that `public_token`.  A `public_token` is one-time use and expires after 30 minutes. You use a `public_token` to initialize Link in [update mode](/docs/link/update-mode) for a particular Item. You can generate a `public_token` for an Item even if you did not use Link to create the Item originally.  The `/item/public_token/create` endpoint is **not** used to create your initial `public_token`. If you have not already received an `access_token` for a specific Item, use Link to obtain your `public_token` instead. See the [Quickstart](/docs/quickstart) for more information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.item_create_public_token_with_http_info(item_public_token_create_request, async_req=True)
        >>> result = thread.get()

        :param item_public_token_create_request: (required)
        :type item_public_token_create_request: ItemPublicTokenCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ItemPublicTokenCreateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'item_public_token_create_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method item_create_public_token" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'item_public_token_create_request' is set
        if self.api_client.client_side_validation and ('item_public_token_create_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['item_public_token_create_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `item_public_token_create_request` when calling `item_create_public_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'item_public_token_create_request' in local_var_params:
            body_params = local_var_params['item_public_token_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/item/public_token/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ItemPublicTokenCreateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
